==> eslint-config-postcss-1.0.0.tgz: package/es5.js <==
module.exports = {
    'rules': {
        'space-before-function-paren': [2, { 'named': 'never' }],
        'no-shadow-restricted-names':  [2],
        'computed-property-spacing':   [2],
        'no-empty-character-class':    [2],
        'no-irregular-whitespace':     [2],
        'no-unexpected-multiline':     [2],
        'no-multiple-empty-lines':     [2],
        'space-return-throw-case':     [2],
        'no-constant-condition':       [2],
        'no-extra-boolean-cast':       [2],
        'no-inner-declarations':       [2],
        'no-this-before-super':        [2],
        'no-use-before-define':        [2],
        'no-array-constructor':        [2],
        'object-curly-spacing':        [2, 'always'],
        'no-floating-decimal':         [2],
        'no-warning-comments':         [2],
        'handle-callback-err':         [2],
        'no-unneeded-ternary':         [2],
        'operator-assignment':         [2],
        'space-before-blocks':         [2],
        'no-native-reassign':          [2],
        'no-trailing-spaces':          [2],
        'operator-linebreak':          [2, 'after'],
        'consistent-return':           [2],
        'no-duplicate-case':           [2],
        'no-invalid-regexp':           [2],
        'no-negated-in-lhs':           [2],
        'constructor-super':           [2],
        'no-nested-ternary':           [2],
        'no-extend-native':            [2],
        'block-scoped-var':            [2],
        'no-control-regex':            [2],
        'no-sparse-arrays':            [2],
        'no-throw-literal':            [2],
        'no-return-assign':            [2],
        'no-const-assign':             [2],
        'no-class-assign':             [2],
        'no-extra-parens':             [2],
        'no-regex-spaces':             [2],
        'no-implied-eval':             [2],
        'no-useless-call':             [2],
        'no-self-compare':             [2],
        'no-octal-escape':             [2],
        'no-new-wrappers':             [2],
        'no-process-exit':             [2],
        'space-infix-ops':             [2],
        'space-unary-ops':             [2],
        'no-cond-assign':              [2],
        'no-func-assign':              [2],
        'no-unreachable':              [2],
        'accessor-pairs':              [2],
        'no-empty-label':              [2],
        'no-fallthrough':              [2],
        'no-path-concat':              [2],
        'no-new-require':              [2],
        'no-spaced-func':              [2],
        'no-unused-vars':              [2],
        'spaced-comment':              [2],
        'block-spacing':               [2],
        'no-delete-var':               [2],
        'comma-spacing':               [2],
        'no-extra-semi':               [2],
        'no-extra-bind':               [2],
        'arrow-spacing':               [2],
        'prefer-spread':               [2],
        'no-new-object':               [2],
        'no-multi-str':                [2],
        'semi-spacing':                [2],
        'no-lonely-if':                [2],
        'dot-notation':                [2],
        'dot-location':                [2, 'property'],
        'comma-dangle':                [2, 'never'],
        'no-dupe-args':                [2],
        'no-dupe-keys':                [2],
        'no-ex-assign':                [2],
        'no-obj-calls':                [2],
        'valid-typeof':                [2],
        'default-case':                [2],
        'no-redeclare':                [2],
        'no-div-regex':                [2],
        'no-sequences':                [2],
        'no-label-var':                [2],
        'comma-style':                 [2],
        'brace-style':                 [2],
        'no-debugger':                 [2],
        'quote-props':                 [2, 'consistent-as-needed'],
        'no-iterator':                 [2],
        'no-new-func':                 [2],
        'complexity':                  [2],
        'new-parens':                  [2],
        'no-eq-null':                  [2],
        'no-bitwise':                  [2],
        'wrap-iife':                   [2],
        'no-caller':                   [2],
        'use-isnan':                   [2],
        'no-labels':                   [2],
        'no-shadow':                   [2],
        'camelcase':                   [2],
        'eol-last':                    [2],
        'no-octal':                    [2],
        'no-empty':                    [2],
        'no-alert':                    [2],
        'no-proto':                    [2],
        'no-undef':                    [2],
        'no-eval':                     [2],
        'no-with':                     [2],
        'no-void':                     [2],
        'max-len':                     [2, 80],
        'new-cap':                     [2],
        'eqeqeq':                      [2],
        'no-new':                      [2],
        'quotes':                      [2, 'single'],
        'indent':                      [2, 4],
        'semi':                        [2, 'always'],
        'yoda':                        [2, 'never']
    },
    'ecmaFeatures': {
        'modules': true
    },
    'env': {
        'node': true,
        'es6':  true
    }
};

==> eslint-config-postcss-2.0.0.tgz: package/es5.js <==
module.exports = {
    'rules': {
        'space-before-function-paren': [2, { 'named': 'never' }],
        'no-shadow-restricted-names':  [2],
        'computed-property-spacing':   [2],
        'no-empty-character-class':    [2],
        'no-irregular-whitespace':     [2],
        'no-unexpected-multiline':     [2],
        'no-multiple-empty-lines':     [2],
        'no-constant-condition':       [2],
        'no-extra-boolean-cast':       [2],
        'no-inner-declarations':       [2],
        'no-this-before-super':        [2],
        'no-use-before-define':        [2],
        'no-array-constructor':        [2],
        'object-curly-spacing':        [2, 'always'],
        'no-floating-decimal':         [2],
        'no-warning-comments':         [2],
        'handle-callback-err':         [2],
        'no-unneeded-ternary':         [2],
        'operator-assignment':         [2],
        'space-before-blocks':         [2],
        'no-native-reassign':          [2],
        'no-trailing-spaces':          [2],
        'operator-linebreak':          [2, 'after'],
        'consistent-return':           [2],
        'no-duplicate-case':           [2],
        'no-invalid-regexp':           [2],
        'no-negated-in-lhs':           [2],
        'constructor-super':           [2],
        'no-nested-ternary':           [2],
        'no-extend-native':            [2],
        'block-scoped-var':            [2],
        'no-control-regex':            [2],
        'no-sparse-arrays':            [2],
        'no-throw-literal':            [2],
        'no-return-assign':            [2],
        'keyword-spacing':             [2],
        'no-const-assign':             [2],
        'no-class-assign':             [2],
        'no-extra-parens':             [2],
        'no-regex-spaces':             [2],
        'no-implied-eval':             [2],
        'no-useless-call':             [2],
        'no-self-compare':             [2],
        'no-octal-escape':             [2],
        'no-new-wrappers':             [2],
        'no-process-exit':             [2],
        'space-infix-ops':             [2],
        'space-unary-ops':             [2],
        'no-cond-assign':              [2],
        'no-func-assign':              [2],
        'no-unreachable':              [2],
        'accessor-pairs':              [2],
        'no-fallthrough':              [2],
        'no-path-concat':              [2],
        'no-new-require':              [2],
        'no-spaced-func':              [2],
        'no-unused-vars':              [2],
        'spaced-comment':              [2],
        'block-spacing':               [2],
        'no-delete-var':               [2],
        'comma-spacing':               [2],
        'no-extra-semi':               [2],
        'no-extra-bind':               [2],
        'arrow-spacing':               [2],
        'prefer-spread':               [2],
        'no-new-object':               [2],
        'no-multi-str':                [2],
        'semi-spacing':                [2],
        'no-lonely-if':                [2],
        'dot-notation':                [2],
        'dot-location':                [2, 'property'],
        'comma-dangle':                [2, 'never'],
        'no-dupe-args':                [2],
        'no-dupe-keys':                [2],
        'no-ex-assign':                [2],
        'no-obj-calls':                [2],
        'valid-typeof':                [2],
        'default-case':                [2],
        'no-redeclare':                [2],
        'no-div-regex':                [2],
        'no-sequences':                [2],
        'no-label-var':                [2],
        'comma-style':                 [2],
        'brace-style':                 [2],
        'no-debugger':                 [2],
        'quote-props':                 [2, 'consistent-as-needed'],
        'no-iterator':                 [2],
        'no-new-func':                 [2],
        'complexity':                  [2],
        'new-parens':                  [2],
        'no-eq-null':                  [2],
        'no-bitwise':                  [2],
        'wrap-iife':                   [2],
        'no-caller':                   [2],
        'use-isnan':                   [2],
        'no-labels':                   [2],
        'no-shadow':                   [2],
        'camelcase':                   [2],
        'eol-last':                    [2],
        'no-octal':                    [2],
        'no-empty':                    [2],
        'no-alert':                    [2],
        'no-proto':                    [2],
        'no-undef':                    [2],
        'no-eval':                     [2],
        'no-with':                     [2],
        'no-void':                     [2],
        'max-len':                     [2, 80],
        'new-cap':                     [2],
        'eqeqeq':                      [2],
        'no-new':                      [2],
        'quotes':                      [2, 'single'],
        'indent':                      [2, 4],
        'semi':                        [2, 'always'],
        'yoda':                        [2, 'never']
    },
    'parserOptions': {
        'sourceType': 'module'
    },
    'env': {
        'node': true,
        'es6':  true
    }
};
